// This file was autogenerated by some hot garbage in the `uniffi` crate.
// Trust me, you don't want to mess with it!

#pragma once

#include <stdbool.h>
#include <stddef.h>
#include <stdint.h>

// The following structs are used to implement the lowest level
// of the FFI, and thus useful to multiple uniffied crates.
// We ensure they are declared exactly once, with a header guard, UNIFFI_SHARED_H.
#ifdef UNIFFI_SHARED_H
    // We also try to prevent mixing versions of shared uniffi header structs.
    // If you add anything to the #else block, you must increment the version suffix in UNIFFI_SHARED_HEADER_V4
    #ifndef UNIFFI_SHARED_HEADER_V4
        #error Combining helper code from multiple versions of uniffi is not supported
    #endif // ndef UNIFFI_SHARED_HEADER_V4
#else
#define UNIFFI_SHARED_H
#define UNIFFI_SHARED_HEADER_V4
// ⚠️ Attention: If you change this #else block (ending in `#endif // def UNIFFI_SHARED_H`) you *must* ⚠️
// ⚠️ increment the version suffix in all instances of UNIFFI_SHARED_HEADER_V4 in this file.           ⚠️

typedef struct RustBuffer
{
    uint64_t capacity;
    uint64_t len;
    uint8_t *_Nullable data;
} RustBuffer;

typedef struct ForeignBytes
{
    int32_t len;
    const uint8_t *_Nullable data;
} ForeignBytes;

// Error definitions
typedef struct RustCallStatus {
    int8_t code;
    RustBuffer errorBuf;
} RustCallStatus;

// ⚠️ Attention: If you change this #else block (ending in `#endif // def UNIFFI_SHARED_H`) you *must* ⚠️
// ⚠️ increment the version suffix in all instances of UNIFFI_SHARED_HEADER_V4 in this file.           ⚠️
#endif // def UNIFFI_SHARED_H
#ifndef UNIFFI_FFIDEF_RUST_FUTURE_CONTINUATION_CALLBACK
#define UNIFFI_FFIDEF_RUST_FUTURE_CONTINUATION_CALLBACK
typedef void (*UniffiRustFutureContinuationCallback)(uint64_t, int8_t
    );

#endif
#ifndef UNIFFI_FFIDEF_FOREIGN_FUTURE_DROPPED_CALLBACK
#define UNIFFI_FFIDEF_FOREIGN_FUTURE_DROPPED_CALLBACK
typedef void (*UniffiForeignFutureDroppedCallback)(uint64_t
    );

#endif
#ifndef UNIFFI_FFIDEF_CALLBACK_INTERFACE_FREE
#define UNIFFI_FFIDEF_CALLBACK_INTERFACE_FREE
typedef void (*UniffiCallbackInterfaceFree)(uint64_t
    );

#endif
#ifndef UNIFFI_FFIDEF_CALLBACK_INTERFACE_CLONE
#define UNIFFI_FFIDEF_CALLBACK_INTERFACE_CLONE
typedef uint64_t (*UniffiCallbackInterfaceClone)(uint64_t
    );

#endif
#ifndef UNIFFI_FFIDEF_FOREIGN_FUTURE_DROPPED_CALLBACK_STRUCT
#define UNIFFI_FFIDEF_FOREIGN_FUTURE_DROPPED_CALLBACK_STRUCT
typedef struct UniffiForeignFutureDroppedCallbackStruct {
    uint64_t handle;
    UniffiForeignFutureDroppedCallback _Nonnull free;
} UniffiForeignFutureDroppedCallbackStruct;

#endif
#ifndef UNIFFI_FFIDEF_FOREIGN_FUTURE_RESULT_U8
#define UNIFFI_FFIDEF_FOREIGN_FUTURE_RESULT_U8
typedef struct UniffiForeignFutureResultU8 {
    uint8_t returnValue;
    RustCallStatus callStatus;
} UniffiForeignFutureResultU8;

#endif
#ifndef UNIFFI_FFIDEF_FOREIGN_FUTURE_COMPLETE_U8
#define UNIFFI_FFIDEF_FOREIGN_FUTURE_COMPLETE_U8
typedef void (*UniffiForeignFutureCompleteU8)(uint64_t, UniffiForeignFutureResultU8
    );

#endif
#ifndef UNIFFI_FFIDEF_FOREIGN_FUTURE_RESULT_I8
#define UNIFFI_FFIDEF_FOREIGN_FUTURE_RESULT_I8
typedef struct UniffiForeignFutureResultI8 {
    int8_t returnValue;
    RustCallStatus callStatus;
} UniffiForeignFutureResultI8;

#endif
#ifndef UNIFFI_FFIDEF_FOREIGN_FUTURE_COMPLETE_I8
#define UNIFFI_FFIDEF_FOREIGN_FUTURE_COMPLETE_I8
typedef void (*UniffiForeignFutureCompleteI8)(uint64_t, UniffiForeignFutureResultI8
    );

#endif
#ifndef UNIFFI_FFIDEF_FOREIGN_FUTURE_RESULT_U16
#define UNIFFI_FFIDEF_FOREIGN_FUTURE_RESULT_U16
typedef struct UniffiForeignFutureResultU16 {
    uint16_t returnValue;
    RustCallStatus callStatus;
} UniffiForeignFutureResultU16;

#endif
#ifndef UNIFFI_FFIDEF_FOREIGN_FUTURE_COMPLETE_U16
#define UNIFFI_FFIDEF_FOREIGN_FUTURE_COMPLETE_U16
typedef void (*UniffiForeignFutureCompleteU16)(uint64_t, UniffiForeignFutureResultU16
    );

#endif
#ifndef UNIFFI_FFIDEF_FOREIGN_FUTURE_RESULT_I16
#define UNIFFI_FFIDEF_FOREIGN_FUTURE_RESULT_I16
typedef struct UniffiForeignFutureResultI16 {
    int16_t returnValue;
    RustCallStatus callStatus;
} UniffiForeignFutureResultI16;

#endif
#ifndef UNIFFI_FFIDEF_FOREIGN_FUTURE_COMPLETE_I16
#define UNIFFI_FFIDEF_FOREIGN_FUTURE_COMPLETE_I16
typedef void (*UniffiForeignFutureCompleteI16)(uint64_t, UniffiForeignFutureResultI16
    );

#endif
#ifndef UNIFFI_FFIDEF_FOREIGN_FUTURE_RESULT_U32
#define UNIFFI_FFIDEF_FOREIGN_FUTURE_RESULT_U32
typedef struct UniffiForeignFutureResultU32 {
    uint32_t returnValue;
    RustCallStatus callStatus;
} UniffiForeignFutureResultU32;

#endif
#ifndef UNIFFI_FFIDEF_FOREIGN_FUTURE_COMPLETE_U32
#define UNIFFI_FFIDEF_FOREIGN_FUTURE_COMPLETE_U32
typedef void (*UniffiForeignFutureCompleteU32)(uint64_t, UniffiForeignFutureResultU32
    );

#endif
#ifndef UNIFFI_FFIDEF_FOREIGN_FUTURE_RESULT_I32
#define UNIFFI_FFIDEF_FOREIGN_FUTURE_RESULT_I32
typedef struct UniffiForeignFutureResultI32 {
    int32_t returnValue;
    RustCallStatus callStatus;
} UniffiForeignFutureResultI32;

#endif
#ifndef UNIFFI_FFIDEF_FOREIGN_FUTURE_COMPLETE_I32
#define UNIFFI_FFIDEF_FOREIGN_FUTURE_COMPLETE_I32
typedef void (*UniffiForeignFutureCompleteI32)(uint64_t, UniffiForeignFutureResultI32
    );

#endif
#ifndef UNIFFI_FFIDEF_FOREIGN_FUTURE_RESULT_U64
#define UNIFFI_FFIDEF_FOREIGN_FUTURE_RESULT_U64
typedef struct UniffiForeignFutureResultU64 {
    uint64_t returnValue;
    RustCallStatus callStatus;
} UniffiForeignFutureResultU64;

#endif
#ifndef UNIFFI_FFIDEF_FOREIGN_FUTURE_COMPLETE_U64
#define UNIFFI_FFIDEF_FOREIGN_FUTURE_COMPLETE_U64
typedef void (*UniffiForeignFutureCompleteU64)(uint64_t, UniffiForeignFutureResultU64
    );

#endif
#ifndef UNIFFI_FFIDEF_FOREIGN_FUTURE_RESULT_I64
#define UNIFFI_FFIDEF_FOREIGN_FUTURE_RESULT_I64
typedef struct UniffiForeignFutureResultI64 {
    int64_t returnValue;
    RustCallStatus callStatus;
} UniffiForeignFutureResultI64;

#endif
#ifndef UNIFFI_FFIDEF_FOREIGN_FUTURE_COMPLETE_I64
#define UNIFFI_FFIDEF_FOREIGN_FUTURE_COMPLETE_I64
typedef void (*UniffiForeignFutureCompleteI64)(uint64_t, UniffiForeignFutureResultI64
    );

#endif
#ifndef UNIFFI_FFIDEF_FOREIGN_FUTURE_RESULT_F32
#define UNIFFI_FFIDEF_FOREIGN_FUTURE_RESULT_F32
typedef struct UniffiForeignFutureResultF32 {
    float returnValue;
    RustCallStatus callStatus;
} UniffiForeignFutureResultF32;

#endif
#ifndef UNIFFI_FFIDEF_FOREIGN_FUTURE_COMPLETE_F32
#define UNIFFI_FFIDEF_FOREIGN_FUTURE_COMPLETE_F32
typedef void (*UniffiForeignFutureCompleteF32)(uint64_t, UniffiForeignFutureResultF32
    );

#endif
#ifndef UNIFFI_FFIDEF_FOREIGN_FUTURE_RESULT_F64
#define UNIFFI_FFIDEF_FOREIGN_FUTURE_RESULT_F64
typedef struct UniffiForeignFutureResultF64 {
    double returnValue;
    RustCallStatus callStatus;
} UniffiForeignFutureResultF64;

#endif
#ifndef UNIFFI_FFIDEF_FOREIGN_FUTURE_COMPLETE_F64
#define UNIFFI_FFIDEF_FOREIGN_FUTURE_COMPLETE_F64
typedef void (*UniffiForeignFutureCompleteF64)(uint64_t, UniffiForeignFutureResultF64
    );

#endif
#ifndef UNIFFI_FFIDEF_FOREIGN_FUTURE_RESULT_RUST_BUFFER
#define UNIFFI_FFIDEF_FOREIGN_FUTURE_RESULT_RUST_BUFFER
typedef struct UniffiForeignFutureResultRustBuffer {
    RustBuffer returnValue;
    RustCallStatus callStatus;
} UniffiForeignFutureResultRustBuffer;

#endif
#ifndef UNIFFI_FFIDEF_FOREIGN_FUTURE_COMPLETE_RUST_BUFFER
#define UNIFFI_FFIDEF_FOREIGN_FUTURE_COMPLETE_RUST_BUFFER
typedef void (*UniffiForeignFutureCompleteRustBuffer)(uint64_t, UniffiForeignFutureResultRustBuffer
    );

#endif
#ifndef UNIFFI_FFIDEF_FOREIGN_FUTURE_RESULT_VOID
#define UNIFFI_FFIDEF_FOREIGN_FUTURE_RESULT_VOID
typedef struct UniffiForeignFutureResultVoid {
    RustCallStatus callStatus;
} UniffiForeignFutureResultVoid;

#endif
#ifndef UNIFFI_FFIDEF_FOREIGN_FUTURE_COMPLETE_VOID
#define UNIFFI_FFIDEF_FOREIGN_FUTURE_COMPLETE_VOID
typedef void (*UniffiForeignFutureCompleteVoid)(uint64_t, UniffiForeignFutureResultVoid
    );

#endif
#ifndef UNIFFI_FFIDEF_CALLBACK_INTERFACE_MOZ_ADS_CONTEXT_ID_PROVIDER_METHOD0
#define UNIFFI_FFIDEF_CALLBACK_INTERFACE_MOZ_ADS_CONTEXT_ID_PROVIDER_METHOD0
typedef void (*UniffiCallbackInterfaceMozAdsContextIdProviderMethod0)(uint64_t, RustBuffer* _Nonnull, 
        RustCallStatus *_Nonnull uniffiCallStatus
    );

#endif
#ifndef UNIFFI_FFIDEF_CALLBACK_INTERFACE_MOZ_ADS_TELEMETRY_METHOD0
#define UNIFFI_FFIDEF_CALLBACK_INTERFACE_MOZ_ADS_TELEMETRY_METHOD0
typedef void (*UniffiCallbackInterfaceMozAdsTelemetryMethod0)(uint64_t, RustBuffer, RustBuffer, void* _Nonnull, 
        RustCallStatus *_Nonnull uniffiCallStatus
    );

#endif
#ifndef UNIFFI_FFIDEF_CALLBACK_INTERFACE_MOZ_ADS_TELEMETRY_METHOD1
#define UNIFFI_FFIDEF_CALLBACK_INTERFACE_MOZ_ADS_TELEMETRY_METHOD1
typedef void (*UniffiCallbackInterfaceMozAdsTelemetryMethod1)(uint64_t, RustBuffer, RustBuffer, void* _Nonnull, 
        RustCallStatus *_Nonnull uniffiCallStatus
    );

#endif
#ifndef UNIFFI_FFIDEF_CALLBACK_INTERFACE_MOZ_ADS_TELEMETRY_METHOD2
#define UNIFFI_FFIDEF_CALLBACK_INTERFACE_MOZ_ADS_TELEMETRY_METHOD2
typedef void (*UniffiCallbackInterfaceMozAdsTelemetryMethod2)(uint64_t, RustBuffer, void* _Nonnull, 
        RustCallStatus *_Nonnull uniffiCallStatus
    );

#endif
#ifndef UNIFFI_FFIDEF_CALLBACK_INTERFACE_MOZ_ADS_TELEMETRY_METHOD3
#define UNIFFI_FFIDEF_CALLBACK_INTERFACE_MOZ_ADS_TELEMETRY_METHOD3
typedef void (*UniffiCallbackInterfaceMozAdsTelemetryMethod3)(uint64_t, RustBuffer, RustBuffer, void* _Nonnull, 
        RustCallStatus *_Nonnull uniffiCallStatus
    );

#endif
#ifndef UNIFFI_FFIDEF_CALLBACK_INTERFACE_MOZ_ADS_TELEMETRY_METHOD4
#define UNIFFI_FFIDEF_CALLBACK_INTERFACE_MOZ_ADS_TELEMETRY_METHOD4
typedef void (*UniffiCallbackInterfaceMozAdsTelemetryMethod4)(uint64_t, RustBuffer, RustBuffer, void* _Nonnull, 
        RustCallStatus *_Nonnull uniffiCallStatus
    );

#endif
#ifndef UNIFFI_FFIDEF_V_TABLE_CALLBACK_INTERFACE_MOZ_ADS_CONTEXT_ID_PROVIDER
#define UNIFFI_FFIDEF_V_TABLE_CALLBACK_INTERFACE_MOZ_ADS_CONTEXT_ID_PROVIDER
typedef struct UniffiVTableCallbackInterfaceMozAdsContextIdProvider {
    UniffiCallbackInterfaceFree _Nonnull uniffiFree;
    UniffiCallbackInterfaceClone _Nonnull uniffiClone;
    UniffiCallbackInterfaceMozAdsContextIdProviderMethod0 _Nonnull contextId;
} UniffiVTableCallbackInterfaceMozAdsContextIdProvider;

#endif
#ifndef UNIFFI_FFIDEF_V_TABLE_CALLBACK_INTERFACE_MOZ_ADS_TELEMETRY
#define UNIFFI_FFIDEF_V_TABLE_CALLBACK_INTERFACE_MOZ_ADS_TELEMETRY
typedef struct UniffiVTableCallbackInterfaceMozAdsTelemetry {
    UniffiCallbackInterfaceFree _Nonnull uniffiFree;
    UniffiCallbackInterfaceClone _Nonnull uniffiClone;
    UniffiCallbackInterfaceMozAdsTelemetryMethod0 _Nonnull recordBuildCacheError;
    UniffiCallbackInterfaceMozAdsTelemetryMethod1 _Nonnull recordClientError;
    UniffiCallbackInterfaceMozAdsTelemetryMethod2 _Nonnull recordClientOperationTotal;
    UniffiCallbackInterfaceMozAdsTelemetryMethod3 _Nonnull recordDeserializationError;
    UniffiCallbackInterfaceMozAdsTelemetryMethod4 _Nonnull recordHttpCacheOutcome;
} UniffiVTableCallbackInterfaceMozAdsTelemetry;

#endif
#ifndef UNIFFI_FFIDEF_UNIFFI_ADS_CLIENT_FN_CLONE_MOZADSCLIENT
#define UNIFFI_FFIDEF_UNIFFI_ADS_CLIENT_FN_CLONE_MOZADSCLIENT
uint64_t uniffi_ads_client_fn_clone_mozadsclient(uint64_t handle, RustCallStatus *_Nonnull out_status
);
#endif
#ifndef UNIFFI_FFIDEF_UNIFFI_ADS_CLIENT_FN_FREE_MOZADSCLIENT
#define UNIFFI_FFIDEF_UNIFFI_ADS_CLIENT_FN_FREE_MOZADSCLIENT
void uniffi_ads_client_fn_free_mozadsclient(uint64_t handle, RustCallStatus *_Nonnull out_status
);
#endif
#ifndef UNIFFI_FFIDEF_UNIFFI_ADS_CLIENT_FN_METHOD_MOZADSCLIENT_CLEAR_CACHE
#define UNIFFI_FFIDEF_UNIFFI_ADS_CLIENT_FN_METHOD_MOZADSCLIENT_CLEAR_CACHE
void uniffi_ads_client_fn_method_mozadsclient_clear_cache(uint64_t uniffi_self, RustCallStatus *_Nonnull out_status
);
#endif
#ifndef UNIFFI_FFIDEF_UNIFFI_ADS_CLIENT_FN_METHOD_MOZADSCLIENT_RECORD_CLICK
#define UNIFFI_FFIDEF_UNIFFI_ADS_CLIENT_FN_METHOD_MOZADSCLIENT_RECORD_CLICK
void uniffi_ads_client_fn_method_mozadsclient_record_click(uint64_t uniffi_self, RustBuffer click_url, RustCallStatus *_Nonnull out_status
);
#endif
#ifndef UNIFFI_FFIDEF_UNIFFI_ADS_CLIENT_FN_METHOD_MOZADSCLIENT_RECORD_IMPRESSION
#define UNIFFI_FFIDEF_UNIFFI_ADS_CLIENT_FN_METHOD_MOZADSCLIENT_RECORD_IMPRESSION
void uniffi_ads_client_fn_method_mozadsclient_record_impression(uint64_t uniffi_self, RustBuffer impression_url, RustCallStatus *_Nonnull out_status
);
#endif
#ifndef UNIFFI_FFIDEF_UNIFFI_ADS_CLIENT_FN_METHOD_MOZADSCLIENT_REPORT_AD
#define UNIFFI_FFIDEF_UNIFFI_ADS_CLIENT_FN_METHOD_MOZADSCLIENT_REPORT_AD
void uniffi_ads_client_fn_method_mozadsclient_report_ad(uint64_t uniffi_self, RustBuffer report_url, RustBuffer reason, RustCallStatus *_Nonnull out_status
);
#endif
#ifndef UNIFFI_FFIDEF_UNIFFI_ADS_CLIENT_FN_METHOD_MOZADSCLIENT_REQUEST_IMAGE_ADS
#define UNIFFI_FFIDEF_UNIFFI_ADS_CLIENT_FN_METHOD_MOZADSCLIENT_REQUEST_IMAGE_ADS
RustBuffer uniffi_ads_client_fn_method_mozadsclient_request_image_ads(uint64_t uniffi_self, RustBuffer moz_ad_requests, RustBuffer options, RustCallStatus *_Nonnull out_status
);
#endif
#ifndef UNIFFI_FFIDEF_UNIFFI_ADS_CLIENT_FN_METHOD_MOZADSCLIENT_REQUEST_SPOC_ADS
#define UNIFFI_FFIDEF_UNIFFI_ADS_CLIENT_FN_METHOD_MOZADSCLIENT_REQUEST_SPOC_ADS
RustBuffer uniffi_ads_client_fn_method_mozadsclient_request_spoc_ads(uint64_t uniffi_self, RustBuffer moz_ad_requests, RustBuffer options, RustCallStatus *_Nonnull out_status
);
#endif
#ifndef UNIFFI_FFIDEF_UNIFFI_ADS_CLIENT_FN_METHOD_MOZADSCLIENT_REQUEST_TILE_ADS
#define UNIFFI_FFIDEF_UNIFFI_ADS_CLIENT_FN_METHOD_MOZADSCLIENT_REQUEST_TILE_ADS
RustBuffer uniffi_ads_client_fn_method_mozadsclient_request_tile_ads(uint64_t uniffi_self, RustBuffer moz_ad_requests, RustBuffer options, RustCallStatus *_Nonnull out_status
);
#endif
#ifndef UNIFFI_FFIDEF_UNIFFI_ADS_CLIENT_FN_CLONE_MOZADSCLIENTBUILDER
#define UNIFFI_FFIDEF_UNIFFI_ADS_CLIENT_FN_CLONE_MOZADSCLIENTBUILDER
uint64_t uniffi_ads_client_fn_clone_mozadsclientbuilder(uint64_t handle, RustCallStatus *_Nonnull out_status
);
#endif
#ifndef UNIFFI_FFIDEF_UNIFFI_ADS_CLIENT_FN_FREE_MOZADSCLIENTBUILDER
#define UNIFFI_FFIDEF_UNIFFI_ADS_CLIENT_FN_FREE_MOZADSCLIENTBUILDER
void uniffi_ads_client_fn_free_mozadsclientbuilder(uint64_t handle, RustCallStatus *_Nonnull out_status
);
#endif
#ifndef UNIFFI_FFIDEF_UNIFFI_ADS_CLIENT_FN_CONSTRUCTOR_MOZADSCLIENTBUILDER_NEW
#define UNIFFI_FFIDEF_UNIFFI_ADS_CLIENT_FN_CONSTRUCTOR_MOZADSCLIENTBUILDER_NEW
uint64_t uniffi_ads_client_fn_constructor_mozadsclientbuilder_new(RustCallStatus *_Nonnull out_status
    
);
#endif
#ifndef UNIFFI_FFIDEF_UNIFFI_ADS_CLIENT_FN_METHOD_MOZADSCLIENTBUILDER_BUILD
#define UNIFFI_FFIDEF_UNIFFI_ADS_CLIENT_FN_METHOD_MOZADSCLIENTBUILDER_BUILD
uint64_t uniffi_ads_client_fn_method_mozadsclientbuilder_build(uint64_t uniffi_self, RustCallStatus *_Nonnull out_status
);
#endif
#ifndef UNIFFI_FFIDEF_UNIFFI_ADS_CLIENT_FN_METHOD_MOZADSCLIENTBUILDER_CACHE_CONFIG
#define UNIFFI_FFIDEF_UNIFFI_ADS_CLIENT_FN_METHOD_MOZADSCLIENTBUILDER_CACHE_CONFIG
uint64_t uniffi_ads_client_fn_method_mozadsclientbuilder_cache_config(uint64_t uniffi_self, RustBuffer cache_config, RustCallStatus *_Nonnull out_status
);
#endif
#ifndef UNIFFI_FFIDEF_UNIFFI_ADS_CLIENT_FN_METHOD_MOZADSCLIENTBUILDER_CONTEXT_ID_PROVIDER
#define UNIFFI_FFIDEF_UNIFFI_ADS_CLIENT_FN_METHOD_MOZADSCLIENTBUILDER_CONTEXT_ID_PROVIDER
uint64_t uniffi_ads_client_fn_method_mozadsclientbuilder_context_id_provider(uint64_t uniffi_self, uint64_t provider, RustCallStatus *_Nonnull out_status
);
#endif
#ifndef UNIFFI_FFIDEF_UNIFFI_ADS_CLIENT_FN_METHOD_MOZADSCLIENTBUILDER_ENVIRONMENT
#define UNIFFI_FFIDEF_UNIFFI_ADS_CLIENT_FN_METHOD_MOZADSCLIENTBUILDER_ENVIRONMENT
uint64_t uniffi_ads_client_fn_method_mozadsclientbuilder_environment(uint64_t uniffi_self, RustBuffer environment, RustCallStatus *_Nonnull out_status
);
#endif
#ifndef UNIFFI_FFIDEF_UNIFFI_ADS_CLIENT_FN_METHOD_MOZADSCLIENTBUILDER_TELEMETRY
#define UNIFFI_FFIDEF_UNIFFI_ADS_CLIENT_FN_METHOD_MOZADSCLIENTBUILDER_TELEMETRY
uint64_t uniffi_ads_client_fn_method_mozadsclientbuilder_telemetry(uint64_t uniffi_self, uint64_t telemetry, RustCallStatus *_Nonnull out_status
);
#endif
#ifndef UNIFFI_FFIDEF_UNIFFI_ADS_CLIENT_FN_CLONE_MOZADSCONTEXTIDPROVIDER
#define UNIFFI_FFIDEF_UNIFFI_ADS_CLIENT_FN_CLONE_MOZADSCONTEXTIDPROVIDER
uint64_t uniffi_ads_client_fn_clone_mozadscontextidprovider(uint64_t handle, RustCallStatus *_Nonnull out_status
);
#endif
#ifndef UNIFFI_FFIDEF_UNIFFI_ADS_CLIENT_FN_FREE_MOZADSCONTEXTIDPROVIDER
#define UNIFFI_FFIDEF_UNIFFI_ADS_CLIENT_FN_FREE_MOZADSCONTEXTIDPROVIDER
void uniffi_ads_client_fn_free_mozadscontextidprovider(uint64_t handle, RustCallStatus *_Nonnull out_status
);
#endif
#ifndef UNIFFI_FFIDEF_UNIFFI_ADS_CLIENT_FN_INIT_CALLBACK_VTABLE_MOZADSCONTEXTIDPROVIDER
#define UNIFFI_FFIDEF_UNIFFI_ADS_CLIENT_FN_INIT_CALLBACK_VTABLE_MOZADSCONTEXTIDPROVIDER
void uniffi_ads_client_fn_init_callback_vtable_mozadscontextidprovider(const UniffiVTableCallbackInterfaceMozAdsContextIdProvider* _Nonnull vtable
);
#endif
#ifndef UNIFFI_FFIDEF_UNIFFI_ADS_CLIENT_FN_METHOD_MOZADSCONTEXTIDPROVIDER_CONTEXT_ID
#define UNIFFI_FFIDEF_UNIFFI_ADS_CLIENT_FN_METHOD_MOZADSCONTEXTIDPROVIDER_CONTEXT_ID
RustBuffer uniffi_ads_client_fn_method_mozadscontextidprovider_context_id(uint64_t uniffi_self, RustCallStatus *_Nonnull out_status
);
#endif
#ifndef UNIFFI_FFIDEF_UNIFFI_ADS_CLIENT_FN_CLONE_MOZADSTELEMETRY
#define UNIFFI_FFIDEF_UNIFFI_ADS_CLIENT_FN_CLONE_MOZADSTELEMETRY
uint64_t uniffi_ads_client_fn_clone_mozadstelemetry(uint64_t handle, RustCallStatus *_Nonnull out_status
);
#endif
#ifndef UNIFFI_FFIDEF_UNIFFI_ADS_CLIENT_FN_FREE_MOZADSTELEMETRY
#define UNIFFI_FFIDEF_UNIFFI_ADS_CLIENT_FN_FREE_MOZADSTELEMETRY
void uniffi_ads_client_fn_free_mozadstelemetry(uint64_t handle, RustCallStatus *_Nonnull out_status
);
#endif
#ifndef UNIFFI_FFIDEF_UNIFFI_ADS_CLIENT_FN_INIT_CALLBACK_VTABLE_MOZADSTELEMETRY
#define UNIFFI_FFIDEF_UNIFFI_ADS_CLIENT_FN_INIT_CALLBACK_VTABLE_MOZADSTELEMETRY
void uniffi_ads_client_fn_init_callback_vtable_mozadstelemetry(const UniffiVTableCallbackInterfaceMozAdsTelemetry* _Nonnull vtable
);
#endif
#ifndef UNIFFI_FFIDEF_UNIFFI_ADS_CLIENT_FN_METHOD_MOZADSTELEMETRY_RECORD_BUILD_CACHE_ERROR
#define UNIFFI_FFIDEF_UNIFFI_ADS_CLIENT_FN_METHOD_MOZADSTELEMETRY_RECORD_BUILD_CACHE_ERROR
void uniffi_ads_client_fn_method_mozadstelemetry_record_build_cache_error(uint64_t uniffi_self, RustBuffer label, RustBuffer value, RustCallStatus *_Nonnull out_status
);
#endif
#ifndef UNIFFI_FFIDEF_UNIFFI_ADS_CLIENT_FN_METHOD_MOZADSTELEMETRY_RECORD_CLIENT_ERROR
#define UNIFFI_FFIDEF_UNIFFI_ADS_CLIENT_FN_METHOD_MOZADSTELEMETRY_RECORD_CLIENT_ERROR
void uniffi_ads_client_fn_method_mozadstelemetry_record_client_error(uint64_t uniffi_self, RustBuffer label, RustBuffer value, RustCallStatus *_Nonnull out_status
);
#endif
#ifndef UNIFFI_FFIDEF_UNIFFI_ADS_CLIENT_FN_METHOD_MOZADSTELEMETRY_RECORD_CLIENT_OPERATION_TOTAL
#define UNIFFI_FFIDEF_UNIFFI_ADS_CLIENT_FN_METHOD_MOZADSTELEMETRY_RECORD_CLIENT_OPERATION_TOTAL
void uniffi_ads_client_fn_method_mozadstelemetry_record_client_operation_total(uint64_t uniffi_self, RustBuffer label, RustCallStatus *_Nonnull out_status
);
#endif
#ifndef UNIFFI_FFIDEF_UNIFFI_ADS_CLIENT_FN_METHOD_MOZADSTELEMETRY_RECORD_DESERIALIZATION_ERROR
#define UNIFFI_FFIDEF_UNIFFI_ADS_CLIENT_FN_METHOD_MOZADSTELEMETRY_RECORD_DESERIALIZATION_ERROR
void uniffi_ads_client_fn_method_mozadstelemetry_record_deserialization_error(uint64_t uniffi_self, RustBuffer label, RustBuffer value, RustCallStatus *_Nonnull out_status
);
#endif
#ifndef UNIFFI_FFIDEF_UNIFFI_ADS_CLIENT_FN_METHOD_MOZADSTELEMETRY_RECORD_HTTP_CACHE_OUTCOME
#define UNIFFI_FFIDEF_UNIFFI_ADS_CLIENT_FN_METHOD_MOZADSTELEMETRY_RECORD_HTTP_CACHE_OUTCOME
void uniffi_ads_client_fn_method_mozadstelemetry_record_http_cache_outcome(uint64_t uniffi_self, RustBuffer label, RustBuffer value, RustCallStatus *_Nonnull out_status
);
#endif
#ifndef UNIFFI_FFIDEF_FFI_ADS_CLIENT_RUSTBUFFER_ALLOC
#define UNIFFI_FFIDEF_FFI_ADS_CLIENT_RUSTBUFFER_ALLOC
RustBuffer ffi_ads_client_rustbuffer_alloc(uint64_t size, RustCallStatus *_Nonnull out_status
);
#endif
#ifndef UNIFFI_FFIDEF_FFI_ADS_CLIENT_RUSTBUFFER_FROM_BYTES
#define UNIFFI_FFIDEF_FFI_ADS_CLIENT_RUSTBUFFER_FROM_BYTES
RustBuffer ffi_ads_client_rustbuffer_from_bytes(ForeignBytes bytes, RustCallStatus *_Nonnull out_status
);
#endif
#ifndef UNIFFI_FFIDEF_FFI_ADS_CLIENT_RUSTBUFFER_FREE
#define UNIFFI_FFIDEF_FFI_ADS_CLIENT_RUSTBUFFER_FREE
void ffi_ads_client_rustbuffer_free(RustBuffer buf, RustCallStatus *_Nonnull out_status
);
#endif
#ifndef UNIFFI_FFIDEF_FFI_ADS_CLIENT_RUSTBUFFER_RESERVE
#define UNIFFI_FFIDEF_FFI_ADS_CLIENT_RUSTBUFFER_RESERVE
RustBuffer ffi_ads_client_rustbuffer_reserve(RustBuffer buf, uint64_t additional, RustCallStatus *_Nonnull out_status
);
#endif
#ifndef UNIFFI_FFIDEF_FFI_ADS_CLIENT_RUST_FUTURE_POLL_U8
#define UNIFFI_FFIDEF_FFI_ADS_CLIENT_RUST_FUTURE_POLL_U8
void ffi_ads_client_rust_future_poll_u8(uint64_t handle, UniffiRustFutureContinuationCallback _Nonnull callback, uint64_t callback_data
);
#endif
#ifndef UNIFFI_FFIDEF_FFI_ADS_CLIENT_RUST_FUTURE_CANCEL_U8
#define UNIFFI_FFIDEF_FFI_ADS_CLIENT_RUST_FUTURE_CANCEL_U8
void ffi_ads_client_rust_future_cancel_u8(uint64_t handle
);
#endif
#ifndef UNIFFI_FFIDEF_FFI_ADS_CLIENT_RUST_FUTURE_FREE_U8
#define UNIFFI_FFIDEF_FFI_ADS_CLIENT_RUST_FUTURE_FREE_U8
void ffi_ads_client_rust_future_free_u8(uint64_t handle
);
#endif
#ifndef UNIFFI_FFIDEF_FFI_ADS_CLIENT_RUST_FUTURE_COMPLETE_U8
#define UNIFFI_FFIDEF_FFI_ADS_CLIENT_RUST_FUTURE_COMPLETE_U8
uint8_t ffi_ads_client_rust_future_complete_u8(uint64_t handle, RustCallStatus *_Nonnull out_status
);
#endif
#ifndef UNIFFI_FFIDEF_FFI_ADS_CLIENT_RUST_FUTURE_POLL_I8
#define UNIFFI_FFIDEF_FFI_ADS_CLIENT_RUST_FUTURE_POLL_I8
void ffi_ads_client_rust_future_poll_i8(uint64_t handle, UniffiRustFutureContinuationCallback _Nonnull callback, uint64_t callback_data
);
#endif
#ifndef UNIFFI_FFIDEF_FFI_ADS_CLIENT_RUST_FUTURE_CANCEL_I8
#define UNIFFI_FFIDEF_FFI_ADS_CLIENT_RUST_FUTURE_CANCEL_I8
void ffi_ads_client_rust_future_cancel_i8(uint64_t handle
);
#endif
#ifndef UNIFFI_FFIDEF_FFI_ADS_CLIENT_RUST_FUTURE_FREE_I8
#define UNIFFI_FFIDEF_FFI_ADS_CLIENT_RUST_FUTURE_FREE_I8
void ffi_ads_client_rust_future_free_i8(uint64_t handle
);
#endif
#ifndef UNIFFI_FFIDEF_FFI_ADS_CLIENT_RUST_FUTURE_COMPLETE_I8
#define UNIFFI_FFIDEF_FFI_ADS_CLIENT_RUST_FUTURE_COMPLETE_I8
int8_t ffi_ads_client_rust_future_complete_i8(uint64_t handle, RustCallStatus *_Nonnull out_status
);
#endif
#ifndef UNIFFI_FFIDEF_FFI_ADS_CLIENT_RUST_FUTURE_POLL_U16
#define UNIFFI_FFIDEF_FFI_ADS_CLIENT_RUST_FUTURE_POLL_U16
void ffi_ads_client_rust_future_poll_u16(uint64_t handle, UniffiRustFutureContinuationCallback _Nonnull callback, uint64_t callback_data
);
#endif
#ifndef UNIFFI_FFIDEF_FFI_ADS_CLIENT_RUST_FUTURE_CANCEL_U16
#define UNIFFI_FFIDEF_FFI_ADS_CLIENT_RUST_FUTURE_CANCEL_U16
void ffi_ads_client_rust_future_cancel_u16(uint64_t handle
);
#endif
#ifndef UNIFFI_FFIDEF_FFI_ADS_CLIENT_RUST_FUTURE_FREE_U16
#define UNIFFI_FFIDEF_FFI_ADS_CLIENT_RUST_FUTURE_FREE_U16
void ffi_ads_client_rust_future_free_u16(uint64_t handle
);
#endif
#ifndef UNIFFI_FFIDEF_FFI_ADS_CLIENT_RUST_FUTURE_COMPLETE_U16
#define UNIFFI_FFIDEF_FFI_ADS_CLIENT_RUST_FUTURE_COMPLETE_U16
uint16_t ffi_ads_client_rust_future_complete_u16(uint64_t handle, RustCallStatus *_Nonnull out_status
);
#endif
#ifndef UNIFFI_FFIDEF_FFI_ADS_CLIENT_RUST_FUTURE_POLL_I16
#define UNIFFI_FFIDEF_FFI_ADS_CLIENT_RUST_FUTURE_POLL_I16
void ffi_ads_client_rust_future_poll_i16(uint64_t handle, UniffiRustFutureContinuationCallback _Nonnull callback, uint64_t callback_data
);
#endif
#ifndef UNIFFI_FFIDEF_FFI_ADS_CLIENT_RUST_FUTURE_CANCEL_I16
#define UNIFFI_FFIDEF_FFI_ADS_CLIENT_RUST_FUTURE_CANCEL_I16
void ffi_ads_client_rust_future_cancel_i16(uint64_t handle
);
#endif
#ifndef UNIFFI_FFIDEF_FFI_ADS_CLIENT_RUST_FUTURE_FREE_I16
#define UNIFFI_FFIDEF_FFI_ADS_CLIENT_RUST_FUTURE_FREE_I16
void ffi_ads_client_rust_future_free_i16(uint64_t handle
);
#endif
#ifndef UNIFFI_FFIDEF_FFI_ADS_CLIENT_RUST_FUTURE_COMPLETE_I16
#define UNIFFI_FFIDEF_FFI_ADS_CLIENT_RUST_FUTURE_COMPLETE_I16
int16_t ffi_ads_client_rust_future_complete_i16(uint64_t handle, RustCallStatus *_Nonnull out_status
);
#endif
#ifndef UNIFFI_FFIDEF_FFI_ADS_CLIENT_RUST_FUTURE_POLL_U32
#define UNIFFI_FFIDEF_FFI_ADS_CLIENT_RUST_FUTURE_POLL_U32
void ffi_ads_client_rust_future_poll_u32(uint64_t handle, UniffiRustFutureContinuationCallback _Nonnull callback, uint64_t callback_data
);
#endif
#ifndef UNIFFI_FFIDEF_FFI_ADS_CLIENT_RUST_FUTURE_CANCEL_U32
#define UNIFFI_FFIDEF_FFI_ADS_CLIENT_RUST_FUTURE_CANCEL_U32
void ffi_ads_client_rust_future_cancel_u32(uint64_t handle
);
#endif
#ifndef UNIFFI_FFIDEF_FFI_ADS_CLIENT_RUST_FUTURE_FREE_U32
#define UNIFFI_FFIDEF_FFI_ADS_CLIENT_RUST_FUTURE_FREE_U32
void ffi_ads_client_rust_future_free_u32(uint64_t handle
);
#endif
#ifndef UNIFFI_FFIDEF_FFI_ADS_CLIENT_RUST_FUTURE_COMPLETE_U32
#define UNIFFI_FFIDEF_FFI_ADS_CLIENT_RUST_FUTURE_COMPLETE_U32
uint32_t ffi_ads_client_rust_future_complete_u32(uint64_t handle, RustCallStatus *_Nonnull out_status
);
#endif
#ifndef UNIFFI_FFIDEF_FFI_ADS_CLIENT_RUST_FUTURE_POLL_I32
#define UNIFFI_FFIDEF_FFI_ADS_CLIENT_RUST_FUTURE_POLL_I32
void ffi_ads_client_rust_future_poll_i32(uint64_t handle, UniffiRustFutureContinuationCallback _Nonnull callback, uint64_t callback_data
);
#endif
#ifndef UNIFFI_FFIDEF_FFI_ADS_CLIENT_RUST_FUTURE_CANCEL_I32
#define UNIFFI_FFIDEF_FFI_ADS_CLIENT_RUST_FUTURE_CANCEL_I32
void ffi_ads_client_rust_future_cancel_i32(uint64_t handle
);
#endif
#ifndef UNIFFI_FFIDEF_FFI_ADS_CLIENT_RUST_FUTURE_FREE_I32
#define UNIFFI_FFIDEF_FFI_ADS_CLIENT_RUST_FUTURE_FREE_I32
void ffi_ads_client_rust_future_free_i32(uint64_t handle
);
#endif
#ifndef UNIFFI_FFIDEF_FFI_ADS_CLIENT_RUST_FUTURE_COMPLETE_I32
#define UNIFFI_FFIDEF_FFI_ADS_CLIENT_RUST_FUTURE_COMPLETE_I32
int32_t ffi_ads_client_rust_future_complete_i32(uint64_t handle, RustCallStatus *_Nonnull out_status
);
#endif
#ifndef UNIFFI_FFIDEF_FFI_ADS_CLIENT_RUST_FUTURE_POLL_U64
#define UNIFFI_FFIDEF_FFI_ADS_CLIENT_RUST_FUTURE_POLL_U64
void ffi_ads_client_rust_future_poll_u64(uint64_t handle, UniffiRustFutureContinuationCallback _Nonnull callback, uint64_t callback_data
);
#endif
#ifndef UNIFFI_FFIDEF_FFI_ADS_CLIENT_RUST_FUTURE_CANCEL_U64
#define UNIFFI_FFIDEF_FFI_ADS_CLIENT_RUST_FUTURE_CANCEL_U64
void ffi_ads_client_rust_future_cancel_u64(uint64_t handle
);
#endif
#ifndef UNIFFI_FFIDEF_FFI_ADS_CLIENT_RUST_FUTURE_FREE_U64
#define UNIFFI_FFIDEF_FFI_ADS_CLIENT_RUST_FUTURE_FREE_U64
void ffi_ads_client_rust_future_free_u64(uint64_t handle
);
#endif
#ifndef UNIFFI_FFIDEF_FFI_ADS_CLIENT_RUST_FUTURE_COMPLETE_U64
#define UNIFFI_FFIDEF_FFI_ADS_CLIENT_RUST_FUTURE_COMPLETE_U64
uint64_t ffi_ads_client_rust_future_complete_u64(uint64_t handle, RustCallStatus *_Nonnull out_status
);
#endif
#ifndef UNIFFI_FFIDEF_FFI_ADS_CLIENT_RUST_FUTURE_POLL_I64
#define UNIFFI_FFIDEF_FFI_ADS_CLIENT_RUST_FUTURE_POLL_I64
void ffi_ads_client_rust_future_poll_i64(uint64_t handle, UniffiRustFutureContinuationCallback _Nonnull callback, uint64_t callback_data
);
#endif
#ifndef UNIFFI_FFIDEF_FFI_ADS_CLIENT_RUST_FUTURE_CANCEL_I64
#define UNIFFI_FFIDEF_FFI_ADS_CLIENT_RUST_FUTURE_CANCEL_I64
void ffi_ads_client_rust_future_cancel_i64(uint64_t handle
);
#endif
#ifndef UNIFFI_FFIDEF_FFI_ADS_CLIENT_RUST_FUTURE_FREE_I64
#define UNIFFI_FFIDEF_FFI_ADS_CLIENT_RUST_FUTURE_FREE_I64
void ffi_ads_client_rust_future_free_i64(uint64_t handle
);
#endif
#ifndef UNIFFI_FFIDEF_FFI_ADS_CLIENT_RUST_FUTURE_COMPLETE_I64
#define UNIFFI_FFIDEF_FFI_ADS_CLIENT_RUST_FUTURE_COMPLETE_I64
int64_t ffi_ads_client_rust_future_complete_i64(uint64_t handle, RustCallStatus *_Nonnull out_status
);
#endif
#ifndef UNIFFI_FFIDEF_FFI_ADS_CLIENT_RUST_FUTURE_POLL_F32
#define UNIFFI_FFIDEF_FFI_ADS_CLIENT_RUST_FUTURE_POLL_F32
void ffi_ads_client_rust_future_poll_f32(uint64_t handle, UniffiRustFutureContinuationCallback _Nonnull callback, uint64_t callback_data
);
#endif
#ifndef UNIFFI_FFIDEF_FFI_ADS_CLIENT_RUST_FUTURE_CANCEL_F32
#define UNIFFI_FFIDEF_FFI_ADS_CLIENT_RUST_FUTURE_CANCEL_F32
void ffi_ads_client_rust_future_cancel_f32(uint64_t handle
);
#endif
#ifndef UNIFFI_FFIDEF_FFI_ADS_CLIENT_RUST_FUTURE_FREE_F32
#define UNIFFI_FFIDEF_FFI_ADS_CLIENT_RUST_FUTURE_FREE_F32
void ffi_ads_client_rust_future_free_f32(uint64_t handle
);
#endif
#ifndef UNIFFI_FFIDEF_FFI_ADS_CLIENT_RUST_FUTURE_COMPLETE_F32
#define UNIFFI_FFIDEF_FFI_ADS_CLIENT_RUST_FUTURE_COMPLETE_F32
float ffi_ads_client_rust_future_complete_f32(uint64_t handle, RustCallStatus *_Nonnull out_status
);
#endif
#ifndef UNIFFI_FFIDEF_FFI_ADS_CLIENT_RUST_FUTURE_POLL_F64
#define UNIFFI_FFIDEF_FFI_ADS_CLIENT_RUST_FUTURE_POLL_F64
void ffi_ads_client_rust_future_poll_f64(uint64_t handle, UniffiRustFutureContinuationCallback _Nonnull callback, uint64_t callback_data
);
#endif
#ifndef UNIFFI_FFIDEF_FFI_ADS_CLIENT_RUST_FUTURE_CANCEL_F64
#define UNIFFI_FFIDEF_FFI_ADS_CLIENT_RUST_FUTURE_CANCEL_F64
void ffi_ads_client_rust_future_cancel_f64(uint64_t handle
);
#endif
#ifndef UNIFFI_FFIDEF_FFI_ADS_CLIENT_RUST_FUTURE_FREE_F64
#define UNIFFI_FFIDEF_FFI_ADS_CLIENT_RUST_FUTURE_FREE_F64
void ffi_ads_client_rust_future_free_f64(uint64_t handle
);
#endif
#ifndef UNIFFI_FFIDEF_FFI_ADS_CLIENT_RUST_FUTURE_COMPLETE_F64
#define UNIFFI_FFIDEF_FFI_ADS_CLIENT_RUST_FUTURE_COMPLETE_F64
double ffi_ads_client_rust_future_complete_f64(uint64_t handle, RustCallStatus *_Nonnull out_status
);
#endif
#ifndef UNIFFI_FFIDEF_FFI_ADS_CLIENT_RUST_FUTURE_POLL_RUST_BUFFER
#define UNIFFI_FFIDEF_FFI_ADS_CLIENT_RUST_FUTURE_POLL_RUST_BUFFER
void ffi_ads_client_rust_future_poll_rust_buffer(uint64_t handle, UniffiRustFutureContinuationCallback _Nonnull callback, uint64_t callback_data
);
#endif
#ifndef UNIFFI_FFIDEF_FFI_ADS_CLIENT_RUST_FUTURE_CANCEL_RUST_BUFFER
#define UNIFFI_FFIDEF_FFI_ADS_CLIENT_RUST_FUTURE_CANCEL_RUST_BUFFER
void ffi_ads_client_rust_future_cancel_rust_buffer(uint64_t handle
);
#endif
#ifndef UNIFFI_FFIDEF_FFI_ADS_CLIENT_RUST_FUTURE_FREE_RUST_BUFFER
#define UNIFFI_FFIDEF_FFI_ADS_CLIENT_RUST_FUTURE_FREE_RUST_BUFFER
void ffi_ads_client_rust_future_free_rust_buffer(uint64_t handle
);
#endif
#ifndef UNIFFI_FFIDEF_FFI_ADS_CLIENT_RUST_FUTURE_COMPLETE_RUST_BUFFER
#define UNIFFI_FFIDEF_FFI_ADS_CLIENT_RUST_FUTURE_COMPLETE_RUST_BUFFER
RustBuffer ffi_ads_client_rust_future_complete_rust_buffer(uint64_t handle, RustCallStatus *_Nonnull out_status
);
#endif
#ifndef UNIFFI_FFIDEF_FFI_ADS_CLIENT_RUST_FUTURE_POLL_VOID
#define UNIFFI_FFIDEF_FFI_ADS_CLIENT_RUST_FUTURE_POLL_VOID
void ffi_ads_client_rust_future_poll_void(uint64_t handle, UniffiRustFutureContinuationCallback _Nonnull callback, uint64_t callback_data
);
#endif
#ifndef UNIFFI_FFIDEF_FFI_ADS_CLIENT_RUST_FUTURE_CANCEL_VOID
#define UNIFFI_FFIDEF_FFI_ADS_CLIENT_RUST_FUTURE_CANCEL_VOID
void ffi_ads_client_rust_future_cancel_void(uint64_t handle
);
#endif
#ifndef UNIFFI_FFIDEF_FFI_ADS_CLIENT_RUST_FUTURE_FREE_VOID
#define UNIFFI_FFIDEF_FFI_ADS_CLIENT_RUST_FUTURE_FREE_VOID
void ffi_ads_client_rust_future_free_void(uint64_t handle
);
#endif
#ifndef UNIFFI_FFIDEF_FFI_ADS_CLIENT_RUST_FUTURE_COMPLETE_VOID
#define UNIFFI_FFIDEF_FFI_ADS_CLIENT_RUST_FUTURE_COMPLETE_VOID
void ffi_ads_client_rust_future_complete_void(uint64_t handle, RustCallStatus *_Nonnull out_status
);
#endif
#ifndef UNIFFI_FFIDEF_UNIFFI_ADS_CLIENT_CHECKSUM_METHOD_MOZADSCLIENT_CLEAR_CACHE
#define UNIFFI_FFIDEF_UNIFFI_ADS_CLIENT_CHECKSUM_METHOD_MOZADSCLIENT_CLEAR_CACHE
uint16_t uniffi_ads_client_checksum_method_mozadsclient_clear_cache(void
    
);
#endif
#ifndef UNIFFI_FFIDEF_UNIFFI_ADS_CLIENT_CHECKSUM_METHOD_MOZADSCLIENT_RECORD_CLICK
#define UNIFFI_FFIDEF_UNIFFI_ADS_CLIENT_CHECKSUM_METHOD_MOZADSCLIENT_RECORD_CLICK
uint16_t uniffi_ads_client_checksum_method_mozadsclient_record_click(void
    
);
#endif
#ifndef UNIFFI_FFIDEF_UNIFFI_ADS_CLIENT_CHECKSUM_METHOD_MOZADSCLIENT_RECORD_IMPRESSION
#define UNIFFI_FFIDEF_UNIFFI_ADS_CLIENT_CHECKSUM_METHOD_MOZADSCLIENT_RECORD_IMPRESSION
uint16_t uniffi_ads_client_checksum_method_mozadsclient_record_impression(void
    
);
#endif
#ifndef UNIFFI_FFIDEF_UNIFFI_ADS_CLIENT_CHECKSUM_METHOD_MOZADSCLIENT_REPORT_AD
#define UNIFFI_FFIDEF_UNIFFI_ADS_CLIENT_CHECKSUM_METHOD_MOZADSCLIENT_REPORT_AD
uint16_t uniffi_ads_client_checksum_method_mozadsclient_report_ad(void
    
);
#endif
#ifndef UNIFFI_FFIDEF_UNIFFI_ADS_CLIENT_CHECKSUM_METHOD_MOZADSCLIENT_REQUEST_IMAGE_ADS
#define UNIFFI_FFIDEF_UNIFFI_ADS_CLIENT_CHECKSUM_METHOD_MOZADSCLIENT_REQUEST_IMAGE_ADS
uint16_t uniffi_ads_client_checksum_method_mozadsclient_request_image_ads(void
    
);
#endif
#ifndef UNIFFI_FFIDEF_UNIFFI_ADS_CLIENT_CHECKSUM_METHOD_MOZADSCLIENT_REQUEST_SPOC_ADS
#define UNIFFI_FFIDEF_UNIFFI_ADS_CLIENT_CHECKSUM_METHOD_MOZADSCLIENT_REQUEST_SPOC_ADS
uint16_t uniffi_ads_client_checksum_method_mozadsclient_request_spoc_ads(void
    
);
#endif
#ifndef UNIFFI_FFIDEF_UNIFFI_ADS_CLIENT_CHECKSUM_METHOD_MOZADSCLIENT_REQUEST_TILE_ADS
#define UNIFFI_FFIDEF_UNIFFI_ADS_CLIENT_CHECKSUM_METHOD_MOZADSCLIENT_REQUEST_TILE_ADS
uint16_t uniffi_ads_client_checksum_method_mozadsclient_request_tile_ads(void
    
);
#endif
#ifndef UNIFFI_FFIDEF_UNIFFI_ADS_CLIENT_CHECKSUM_METHOD_MOZADSCLIENTBUILDER_BUILD
#define UNIFFI_FFIDEF_UNIFFI_ADS_CLIENT_CHECKSUM_METHOD_MOZADSCLIENTBUILDER_BUILD
uint16_t uniffi_ads_client_checksum_method_mozadsclientbuilder_build(void
    
);
#endif
#ifndef UNIFFI_FFIDEF_UNIFFI_ADS_CLIENT_CHECKSUM_METHOD_MOZADSCLIENTBUILDER_CACHE_CONFIG
#define UNIFFI_FFIDEF_UNIFFI_ADS_CLIENT_CHECKSUM_METHOD_MOZADSCLIENTBUILDER_CACHE_CONFIG
uint16_t uniffi_ads_client_checksum_method_mozadsclientbuilder_cache_config(void
    
);
#endif
#ifndef UNIFFI_FFIDEF_UNIFFI_ADS_CLIENT_CHECKSUM_METHOD_MOZADSCLIENTBUILDER_CONTEXT_ID_PROVIDER
#define UNIFFI_FFIDEF_UNIFFI_ADS_CLIENT_CHECKSUM_METHOD_MOZADSCLIENTBUILDER_CONTEXT_ID_PROVIDER
uint16_t uniffi_ads_client_checksum_method_mozadsclientbuilder_context_id_provider(void
    
);
#endif
#ifndef UNIFFI_FFIDEF_UNIFFI_ADS_CLIENT_CHECKSUM_METHOD_MOZADSCLIENTBUILDER_ENVIRONMENT
#define UNIFFI_FFIDEF_UNIFFI_ADS_CLIENT_CHECKSUM_METHOD_MOZADSCLIENTBUILDER_ENVIRONMENT
uint16_t uniffi_ads_client_checksum_method_mozadsclientbuilder_environment(void
    
);
#endif
#ifndef UNIFFI_FFIDEF_UNIFFI_ADS_CLIENT_CHECKSUM_METHOD_MOZADSCLIENTBUILDER_TELEMETRY
#define UNIFFI_FFIDEF_UNIFFI_ADS_CLIENT_CHECKSUM_METHOD_MOZADSCLIENTBUILDER_TELEMETRY
uint16_t uniffi_ads_client_checksum_method_mozadsclientbuilder_telemetry(void
    
);
#endif
#ifndef UNIFFI_FFIDEF_UNIFFI_ADS_CLIENT_CHECKSUM_METHOD_MOZADSCONTEXTIDPROVIDER_CONTEXT_ID
#define UNIFFI_FFIDEF_UNIFFI_ADS_CLIENT_CHECKSUM_METHOD_MOZADSCONTEXTIDPROVIDER_CONTEXT_ID
uint16_t uniffi_ads_client_checksum_method_mozadscontextidprovider_context_id(void
    
);
#endif
#ifndef UNIFFI_FFIDEF_UNIFFI_ADS_CLIENT_CHECKSUM_METHOD_MOZADSTELEMETRY_RECORD_BUILD_CACHE_ERROR
#define UNIFFI_FFIDEF_UNIFFI_ADS_CLIENT_CHECKSUM_METHOD_MOZADSTELEMETRY_RECORD_BUILD_CACHE_ERROR
uint16_t uniffi_ads_client_checksum_method_mozadstelemetry_record_build_cache_error(void
    
);
#endif
#ifndef UNIFFI_FFIDEF_UNIFFI_ADS_CLIENT_CHECKSUM_METHOD_MOZADSTELEMETRY_RECORD_CLIENT_ERROR
#define UNIFFI_FFIDEF_UNIFFI_ADS_CLIENT_CHECKSUM_METHOD_MOZADSTELEMETRY_RECORD_CLIENT_ERROR
uint16_t uniffi_ads_client_checksum_method_mozadstelemetry_record_client_error(void
    
);
#endif
#ifndef UNIFFI_FFIDEF_UNIFFI_ADS_CLIENT_CHECKSUM_METHOD_MOZADSTELEMETRY_RECORD_CLIENT_OPERATION_TOTAL
#define UNIFFI_FFIDEF_UNIFFI_ADS_CLIENT_CHECKSUM_METHOD_MOZADSTELEMETRY_RECORD_CLIENT_OPERATION_TOTAL
uint16_t uniffi_ads_client_checksum_method_mozadstelemetry_record_client_operation_total(void
    
);
#endif
#ifndef UNIFFI_FFIDEF_UNIFFI_ADS_CLIENT_CHECKSUM_METHOD_MOZADSTELEMETRY_RECORD_DESERIALIZATION_ERROR
#define UNIFFI_FFIDEF_UNIFFI_ADS_CLIENT_CHECKSUM_METHOD_MOZADSTELEMETRY_RECORD_DESERIALIZATION_ERROR
uint16_t uniffi_ads_client_checksum_method_mozadstelemetry_record_deserialization_error(void
    
);
#endif
#ifndef UNIFFI_FFIDEF_UNIFFI_ADS_CLIENT_CHECKSUM_METHOD_MOZADSTELEMETRY_RECORD_HTTP_CACHE_OUTCOME
#define UNIFFI_FFIDEF_UNIFFI_ADS_CLIENT_CHECKSUM_METHOD_MOZADSTELEMETRY_RECORD_HTTP_CACHE_OUTCOME
uint16_t uniffi_ads_client_checksum_method_mozadstelemetry_record_http_cache_outcome(void
    
);
#endif
#ifndef UNIFFI_FFIDEF_UNIFFI_ADS_CLIENT_CHECKSUM_CONSTRUCTOR_MOZADSCLIENTBUILDER_NEW
#define UNIFFI_FFIDEF_UNIFFI_ADS_CLIENT_CHECKSUM_CONSTRUCTOR_MOZADSCLIENTBUILDER_NEW
uint16_t uniffi_ads_client_checksum_constructor_mozadsclientbuilder_new(void
    
);
#endif
#ifndef UNIFFI_FFIDEF_FFI_ADS_CLIENT_UNIFFI_CONTRACT_VERSION
#define UNIFFI_FFIDEF_FFI_ADS_CLIENT_UNIFFI_CONTRACT_VERSION
uint32_t ffi_ads_client_uniffi_contract_version(void
    
);
#endif

